nikola.plugins.task package
===========================

Subpackages
-----------

.. toctree::

    nikola.plugins.task.sitemap

Submodules
----------

nikola.plugins.task.archive module
----------------------------------

.. automodule:: nikola.plugins.task.archive
    :members:
    :undoc-members:
    :show-inheritance:

nikola.plugins.task.authors module
----------------------------------

.. automodule:: nikola.plugins.task.authors
    :members:
    :undoc-members:
    :show-inheritance:

nikola.plugins.task.bundles module
----------------------------------

.. automodule:: nikola.plugins.task.bundles
    :members:
    :undoc-members:
    :show-inheritance:

nikola.plugins.task.copy_assets module
--------------------------------------

.. automodule:: nikola.plugins.task.copy_assets
    :members:
    :undoc-members:
    :show-inheritance:

nikola.plugins.task.copy_files module
-------------------------------------

.. automodule:: nikola.plugins.task.copy_files
    :members:
    :undoc-members:
    :show-inheritance:

nikola.plugins.task.galleries module
------------------------------------

.. automodule:: nikola.plugins.task.galleries
    :members:
    :undoc-members:
    :show-inheritance:

nikola.plugins.task.gzip module
-------------------------------

.. automodule:: nikola.plugins.task.gzip
    :members:
    :undoc-members:
    :show-inheritance:

nikola.plugins.task.indexes module
----------------------------------

.. automodule:: nikola.plugins.task.indexes
    :members:
    :undoc-members:
    :show-inheritance:

nikola.plugins.task.listings module
-----------------------------------

.. automodule:: nikola.plugins.task.listings
    :members:
    :undoc-members:
    :show-inheritance:

nikola.plugins.task.pages module
--------------------------------

.. automodule:: nikola.plugins.task.pages
    :members:
    :undoc-members:
    :show-inheritance:

nikola.plugins.task.posts module
--------------------------------

.. automodule:: nikola.plugins.task.posts
    :members:
    :undoc-members:
    :show-inheritance:

nikola.plugins.task.py3_switch module
-------------------------------------

.. automodule:: nikola.plugins.task.py3_switch
    :members:
    :undoc-members:
    :show-inheritance:

nikola.plugins.task.redirect module
-----------------------------------

.. automodule:: nikola.plugins.task.redirect
    :members:
    :undoc-members:
    :show-inheritance:

nikola.plugins.task.robots module
---------------------------------

.. automodule:: nikola.plugins.task.robots
    :members:
    :undoc-members:
    :show-inheritance:

nikola.plugins.task.rss module
------------------------------

.. automodule:: nikola.plugins.task.rss
    :members:
    :undoc-members:
    :show-inheritance:

nikola.plugins.task.scale_images module
---------------------------------------

.. automodule:: nikola.plugins.task.scale_images
    :members:
    :undoc-members:
    :show-inheritance:

nikola.plugins.task.sources module
----------------------------------

.. automodule:: nikola.plugins.task.sources
    :members:
    :undoc-members:
    :show-inheritance:

nikola.plugins.task.tags module
-------------------------------

.. automodule:: nikola.plugins.task.tags
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: nikola.plugins.task
    :members:
    :undoc-members:
    :show-inheritance:
